import { Component } from 'preact';
import style from '../routes/snippet/style';
import { compiler } from 'markdown-to-jsx';
import { UnControlled as CodeMirror} from 'react-codemirror2'
require('codemirror/mode/clike/clike');
require('codemirror/lib/codemirror.css');
require('codemirror/theme/material.css');

import {
    Accordion,
    AccordionItem,
    AccordionItemHeading,
    AccordionItemButton,
    AccordionItemPanel,
} from 'react-accessible-accordion';
import 'react-accessible-accordion/dist/fancy-example.css';

export default class TemplateResponse extends Component {
    render() {
        const {
            apiError,
            passed,
            setRef,
            runCode,
            loading,
            onSubmit,
            codeResponses,
            onChange,
            question,
            submittedOnce,
            submissionsLeft,
            value
        } = this.props;
        
        return (
            <div>
                <p class={style.prompt}>{compiler(question.prompt)}</p>
                <p>You have <span class={style.submissionsLeft}>{submissionsLeft} submissions left</span>.</p>
                <CodeMirror
                    value={value}
                    detach={true}
                    options={{
                        mode: 'text/x-java',
                        theme: 'material',
                        gutter: false,
                        lineNumbers: true,
                        tabSize: 4,
                        smartIndent: true,
                    }}
                    onChange={onChange}
                />
                { codeResponses.length || loading ?
                    (<div class={style.codeResults}>
                        <div class={style.codeResultsHeader}><p>Test Case Results</p></div>
                        <Accordion allowZeroExpanded={true}>
                            { loading ? <div class={style.loading}>Loading</div> : codeResponses.map((res, idx) => (
                                <AccordionItem>
                                    <AccordionItemHeading>
                                        <AccordionItemButton>
                                            <div class={style.testResponse}>
                                                <span>Test {idx}</span>
                                                <span class={res.pass ? style.tcPassed : style.tcFailed}></span>
                                            </div>
                                        </AccordionItemButton>
                                    </AccordionItemHeading>
                                    <AccordionItemPanel>
                                        <p class={style.systemOutput}>{res.output}</p>
                                    </AccordionItemPanel>  
                                </AccordionItem>
                            ))}
                        </Accordion>
                    </div>)
                : apiError ? <div class={style.error}>{apiError}</div> : '' }
                <form onSubmit={onSubmit}>
                    <button type="button" class={loading ? style.disabledRunCode : style.runCodeButton} onClick={runCode} disabled={loading}>Submit Code</button>
                    <button type="submit" class={loading || !submittedOnce ? style.disabledButton : style.button} disabled={loading || !submittedOnce}>Next Question</button>
                </form>
            </div>
        );
    }
}